@@ -79,7 +79,7 @@ impl Display for MappingPath {
 
 struct MappingPathVisitor;
 
-impl<'de> serde::de::Visitor<'de> for MappingPathVisitor {
+impl serde::de::Visitor<'_> for MappingPathVisitor {
     type Value = MappingPath;
 
     fn expecting(&self, formatter: &mut Formatter) -> std::fmt::Result {
@@ -2009,13 +2009,13 @@ tasks:
             default: None,
             location: UnixPath::new(DEFAULT_LOCATION).to_owned(),
             user: DEFAULT_USER.to_owned(),
-            command_prefix: "set -euo pipefail".to_owned(),
+            command_prefix: "set -euxo pipefail".to_owned(),
             tasks,
         };
 
         assert_eq!(
             command(&toastfile, &toastfile.tasks["foo"]),
-            "set -euo pipefail".to_owned(),
+            "set -euxo pipefail".to_owned(),
         );
     }
 
@@ -2079,7 +2079,7 @@ tasks:
                 location: None,
                 user: None,
                 command: String::new(),
-                command_prefix: Some("set -euo pipefail".to_owned()),
+                command_prefix: Some("set -euxo pipefail".to_owned()),
                 extra_docker_arguments: vec![],
             },
         );
@@ -2095,7 +2095,7 @@ tasks:
 
         assert_eq!(
             command(&toastfile, &toastfile.tasks["foo"]),
-            "set -euo pipefail".to_owned(),
+            "set -euxo pipefail".to_owned(),
         );
     }
 
@@ -2119,7 +2119,7 @@ tasks:
                 location: None,
                 user: None,
                 command: "echo hello".to_owned(),
-                command_prefix: Some("set -euo pipefail".to_owned()),
+                command_prefix: Some("set -euxo pipefail".to_owned()),
                 extra_docker_arguments: vec![],
             },
         );
@@ -2135,7 +2135,7 @@ tasks:
 
         assert_eq!(
             command(&toastfile, &toastfile.tasks["foo"]),
-            "set -euo pipefail\necho hello".to_owned(),
+            "set -euxo pipefail\necho hello".to_owned(),
         );
     }
 }
